==> aliyun-python-sdk-companyreg-1.2.0.tar.gz: aliyun-python-sdk-companyreg-1.2.0/aliyunsdkcompanyreg/request/v20201022/PrintAcctgTransRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class PrintAcctgTransRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'PrintAcctgTrans','companyreg')
		self.set_method('GET')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ShowCustomComments(self):
		return self.get_query_params().get('ShowCustomComments')

	def set_ShowCustomComments(self,ShowCustomComments):
		self.add_query_param('ShowCustomComments',ShowCustomComments)

	def get_PrintStyle(self):
		return self.get_query_params().get('PrintStyle')

	def set_PrintStyle(self,PrintStyle):
		self.add_query_param('PrintStyle',PrintStyle)

	def get_BizId(self):
		return self.get_query_params().get('BizId')

	def set_BizId(self,BizId):
		self.add_query_param('BizId',BizId)

	def get_PrintCount(self):
		return self.get_query_params().get('PrintCount')

	def set_PrintCount(self,PrintCount):
		self.add_query_param('PrintCount',PrintCount)

	def get_VoucherIds(self):
		return self.get_query_params().get('VoucherIds')

	def set_VoucherIds(self,VoucherIds):
		self.add_query_param('VoucherIds',VoucherIds)

==> aliyun-python-sdk-companyreg-1.2.1.tar.gz: aliyun-python-sdk-companyreg-1.2.1/aliyunsdkcompanyreg/request/v20201022/PrintAcctgTransRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class PrintAcctgTransRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'PrintAcctgTrans')
		self.set_method('GET')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ShowCustomComments(self):
		return self.get_query_params().get('ShowCustomComments')

	def set_ShowCustomComments(self,ShowCustomComments):
		self.add_query_param('ShowCustomComments',ShowCustomComments)

	def get_PrintStyle(self):
		return self.get_query_params().get('PrintStyle')

	def set_PrintStyle(self,PrintStyle):
		self.add_query_param('PrintStyle',PrintStyle)

	def get_BizId(self):
		return self.get_query_params().get('BizId')

	def set_BizId(self,BizId):
		self.add_query_param('BizId',BizId)

	def get_PrintCount(self):
		return self.get_query_params().get('PrintCount')

	def set_PrintCount(self,PrintCount):
		self.add_query_param('PrintCount',PrintCount)

	def get_VoucherIds(self):
		return self.get_query_params().get('VoucherIds')

	def set_VoucherIds(self,VoucherIds):
		self.add_query_param('VoucherIds',VoucherIds)
